// render first this file with +fn16 (w/h - 16:9) and copy image in this folder

#version 3.7;

#declare PHOT      = 0;  // photons 0=out; 1=save photons; 2=load photons
#declare RAD       = 0;  // radiosity quality settings 0=out; 1=acceptable; 5=good
                
global_settings {
        #declare a_g = 1;
        assumed_gamma a_g
        max_trace_level 5
        //subsurface {radiosity on samples 200,200}
        noise_generator 3
        #if (PHOT > 0)
                photons {
                        spacing 0.05
                        autostop 0
                        jitter 1
                        #if (PHOT = 1)
                                save_file "pov.ph"
                        #else
                                load_file "pov.ph"
                        #end                        
                }                                                               
        #end  
        #if(RAD > 0)
                radiosity {
                        pretrace_start 0.08
                        pretrace_end   0.04/RAD
                        count 60*RAD                
                        nearest_count min (20, RAD)      
                        error_bound 2/RAD
                        low_error_factor 0.5      
                        recursion_limit 1      
                        gray_threshold 0  
                        minimum_reuse 0.015 
                        brightness 1      
                        adc_bailout 0.005
                        normal off
                        media off
                }
        #end
}        

#include "stdinc.inc"
        
#declare camloc = <50,0,-201.5>;
#declare lookat = <0,0,0>;
#declare camang = 46;
#declare camrig = 1;

camera {
        location camloc   
        right x*image_width/image_height*camrig  
        look_at lookat
        angle camang
}

sphere {
        0, 10000
        texture {
                pigment {color rgb 1}
                finish {emission 1 diffuse 0}
        } 
}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "chinese_coin_POV_geom.inc"
#include "golden_column_POV_geom.inc"
#include "man_bust_POV_geom.inc" 

#declare set_up =
union {
        object {
                chinese_coin_
                translate <0,14.5865001678467,0>
                scale 88/29.3090629577637*<-1,1,1> 
                rotate y*135
                translate <-41,-40,0>
        } 
        object {
                golden_column_
                translate <-10.4126052856445+20,-176,-9.0140266418457+20>
                scale 18/966.555877685547*7.5 
                rotate y*260
                translate <43,-40,0>
        }
        object {
                man_bust_
                translate <-21.19413,266.5959,75.80349>
                scale 45/465.3022*<-1,1,1> 
                rotate y*210
                translate <43,0,0>
        }
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// Michael Andrews  Death of a Cliche ...  http://news.povray.org/povray.binaries.scene-files/attachment/%3C3CC3D3E5.38B9F487@reading.ac.uk%3E/

#macro Proximity_Pattern (Object, Range, Count) // by ABX - modified by MCA

#local P = function {pattern {object {Object}}};
#local Range = Range+0*x;
#local X = Range.x;
#local Y = Range.y;
#local Z = Range.z;
#local C = max (int (Count),1);
#local mC = C;
#local Phi = 2/(sqrt (5)-1);
function {
	(1/C)*(
	#while (C)
		#local C1 = vrotate (y, <degrees (acos (1-2*(C-0.5)/mC)), (C-0.5)*Phi*360,0>);
		#local C1x = C1.x;
		#local C1y = C1.y;
		#local C1z = C1.z;
		P (
			x+X*C1x*f_noise_generator (100*(x+C1x),100*(y+C1y),100*(z+C1z),2),
			y+Y*C1y*f_noise_generator (100*(x+C1x),100*(y+C1y),100*(z+C1z),2),
			z+Z*C1z*f_noise_generator (100*(x+C1x),100*(y+C1y),100*(z+C1z),2)
		)
		#local C = C-1;
		#if (C)
			+
		#end
	#end
	)
}

#end

#declare Tb =
texture {
        pigment {color rgb 1}
        finish {emission 1 diffuse 0 ambient 0}
} 

#declare Td =
texture {
        pigment {color rgb 0}
        finish {emission 1 diffuse 0 ambient 0}
}

#declare T2 =
material {
	    texture {
                Proximity_Pattern (set_up, 0.2*8, 255)
                texture_map {
                	    [0      Tb]
                	    [1      Td]
                }
        }
	    interior {ior 1}
	    scale 1
} 

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

object {
        set_up
        material {T2}
} 
//plane {y,-40 pigment {color rgb x} finish {emission 1}}
